@@ -1,9 +1,14 @@
 import numpy as np
 import zmq
 import time
+import os.path
+import sys
 import ad_interface_functions
 import trajectory_planning_helpers as tph
 
+path_root2Module = os.path.join(os.path.abspath(__file__).split('tpa_map_interface')[0], 'tpa_map_interface')
+sys.path.append(path_root2Module)
+
 import tpa_map_interface.import_veh_dyn_info
 
 """
@@ -239,10 +244,12 @@ class MapInterface:
                 raise ValueError('TPA MapInterface: wrong shape of position data during local gg request!')
 
         # check if velocity dependence is enabled and velocity values are provided
-        if not self.__bool_enable_velocitydependence and velocity_mps.size != 0:
-            raise ValueError('TPA MapInterface: velocity for velocity dependent acc. limits request is provided, but velocity dependence is disbaled!')
 
-        elif self.__bool_enable_velocitydependence and velocity_mps.size == 0:
+        # TODO: uncomment when trajectory planner is ready
+        # if not self.__bool_enable_velocitydependence and velocity_mps.size != 0:
+        #    raise ValueError('TPA MapInterface: velocity for velocity dependent acc. limits request is provided, but velocity dependence is disbaled!')
+
+        if self.__bool_enable_velocitydependence and velocity_mps.size == 0:
             raise ValueError('TPA MapInterface: velocity dependence is enabled, but no velocity is provided for request!')
 
         # TODO check if velocity array has correct shape and dimension
